@@ -37,12 +37,15 @@ class ENDPOINTS:
     TRACK_GOAL = "/server-side/track-goal"
     PUSH = "/server-side/push"
     BATCH_EVENTS = "/server-side/batch-events"
+    EVENTS = "/events/t"
 
 
 class EVENTS:
     TRACK_USER = "track-user"
     TRACK_GOAL = "track-goal"
     PUSH = "push"
+    VWO_VARIATION_SHOWN = "vwo_variationShown"
+    VWO_SYNC_VISITOR_PROP = "vwo_syncVisitorProp"
 
 
 class DATA_TYPE:
@@ -106,6 +109,11 @@ class PUSH_API:
 PY_VARIABLE_TYPES = {"string": str, "integer": int, "double": float, "boolean": bool, "json": dict}
 
 
+class SEGMENTATION_TYPES:
+    WHITELISTING = "whitelisting"
+    PRE_SEGMENTATION = "pre_segmentation"
+
+
 # For exposing log levels to vwo_instance
 class LOG_LEVELS:
     DEBUG = logging.DEBUG
