@@ -1,4 +1,4 @@
-# Copyright 2019 Wingify Software Pvt. Ltd.
+# Copyright 2019-2021 Wingify Software Pvt. Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,13 +18,13 @@ import uuid
 from ..enums.log_message_enum import LogMessageEnum
 from ..enums.file_name_enum import FileNameEnum
 from ..enums.log_level_enum import LogLevelEnum
-from ..logger.logger_manager import VWOLogger
+from ..logger import VWOLogger
 
-VWO_NAMESPACE = uuid.uuid5(uuid.NAMESPACE_URL, 'https://vwo.com')
+VWO_NAMESPACE = uuid.uuid5(uuid.NAMESPACE_URL, "https://vwo.com")
 FILE = FileNameEnum.Helpers.UuidUtil
 
 
-def generator_for(user_id, account_id):
+def generate_for(user_id, account_id):
     """ Generates desired UUID
 
     Args:
@@ -40,16 +40,13 @@ def generator_for(user_id, account_id):
     user_id_namespace = generate(VWO_NAMESPACE, account_id)
     uuid_for_account_user_id = generate(user_id_namespace, user_id)
 
-    desired_uuid = str(uuid_for_account_user_id).replace('-', '').upper()
+    desired_uuid = str(uuid_for_account_user_id).replace("-", "").upper()
 
     VWOLogger.getInstance().log(
         LogLevelEnum.DEBUG,
         LogMessageEnum.DEBUG_MESSAGES.UUID_FOR_USER.format(
-            file=FILE,
-            user_id=user_id,
-            account_id=account_id,
-            desired_uuid=desired_uuid
-        )
+            file=FILE, user_id=user_id, account_id=account_id, desired_uuid=desired_uuid
+        ),
     )
     return desired_uuid
 
